.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Configuration
===============
``hckr`` supports various of config commands which helps in configuring other commands, eg. ``hckr db`` command.

.. important::
     ``DEFAULT`` config is the parent of all other configurations and others will inherit its values if not overridden

.. tip::
   More commands will be added in future updates. Stay tuned!


commands
---------------
.. toctree::
    config
    configure

